# 🐋 Blue DeepSeek

🌀 `@deepseek` is a [command interface](https://github.com/kamangir/awesome-bash-cli) (`abcli`) to the [DeepSeek](https://www.deepseek.com/).

```bash
pip install blue-deepseek
```

---


[![pylint](https://github.com/kamangir/blue-deepseek/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/blue-deepseek/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/blue-deepseek/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/blue-deepseek/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/blue-deepseek/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/blue-deepseek/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/blue-deepseek.svg)](https://pypi.org/project/blue-deepseek/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/blue-deepseek)](https://pypistats.org/packages/blue-deepseek)

built by 🌀 [`blue_options-4.197.1`](https://github.com/kamangir/awesome-bash-cli), based on 🐋 [`blue_deepseek-4.7.1`](https://github.com/kamangir/blue-deepseek).
